@@ -24,8 +24,10 @@ def addEMSProgramsBase(self, ScriptType: str = None, verboseMode: bool = True):
             Program_Line_2='set ComfTemp = RMOT*0.33+18.8',
             Program_Line_3='elseif AdapStand == 2',
             Program_Line_4='set ComfTemp = PMOT*0.31+17.8',
-            Program_Line_5='endif'
-            )
+            Program_Line_5='elseif AdapStand == 3',
+            Program_Line_6='set ComfTemp = PMOT*0.37+16.8',
+            Program_Line_7='endif'
+        )
         if verboseMode:
             print('Added - SetComfTemp Program')
     #    print([program for program in self.idf1.idfobjects['EnergyManagementSystem:Program'] if program.Name == 'SetComfTemp'])
@@ -40,78 +42,78 @@ def addEMSProgramsBase(self, ScriptType: str = None, verboseMode: bool = True):
                 Name='CountHours_'+zonename,
                 Program_Line_1='if (AdapStand == 1 )',
                 Program_Line_2='if (RMOT >= AHSTall) && (RMOT <= ACSTaul)',
-                Program_Line_3='if ('+zonename+'_OpT <= ACSTnoTol)',
-                Program_Line_4='if ('+zonename+'_OpT >= AHSTnoTol)',
-                Program_Line_5='set ComfHours_'+zonename+' = 1*ZoneTimeStep',
-                Program_Line_6='set DiscomfAppHotHours_'+zonename+' = 0',
-                Program_Line_7='set DiscomfAppColdHours_'+zonename+' = 0',
-                Program_Line_8='set DiscomfNonAppHotHours_'+zonename+' = 0',
-                Program_Line_9='set DiscomfNonAppColdHours_'+zonename+' = 0',
+                Program_Line_3='if (' + zonename + '_OpT <= ACSTnoTol)',
+                Program_Line_4='if (' + zonename + '_OpT >= AHSTnoTol)',
+                Program_Line_5='set ComfHours_' + zonename + ' = 1*ZoneTimeStep',
+                Program_Line_6='set DiscomfAppHotHours_' + zonename + ' = 0',
+                Program_Line_7='set DiscomfAppColdHours_' + zonename + ' = 0',
+                Program_Line_8='set DiscomfNonAppHotHours_' + zonename + ' = 0',
+                Program_Line_9='set DiscomfNonAppColdHours_' + zonename + ' = 0',
                 Program_Line_10='endif',
-                Program_Line_11='elseif ('+zonename+'_OpT > ACSTnoTol)',
-                Program_Line_12='set ComfHours_'+zonename+' = 0',
-                Program_Line_13='set DiscomfAppHotHours_'+zonename+' = 1*ZoneTimeStep',
-                Program_Line_14='set DiscomfAppColdHours_'+zonename+' = 0',
-                Program_Line_15='set DiscomfNonAppHotHours_'+zonename+' = 0',
-                Program_Line_16='set DiscomfNonAppColdHours_'+zonename+' = 0',
-                Program_Line_17='elseif ('+zonename+'_OpT < AHSTnoTol)',
-                Program_Line_18='set ComfHours_'+zonename+' = 0',
-                Program_Line_19='set DiscomfAppHotHours_'+zonename+' = 0',
-                Program_Line_20='set DiscomfAppColdHours_'+zonename+' = 1*ZoneTimeStep',
-                Program_Line_21='set DiscomfNonAppHotHours_'+zonename+' = 0',
-                Program_Line_22='set DiscomfNonAppColdHours_'+zonename+' = 0',
+                Program_Line_11='elseif (' + zonename + '_OpT > ACSTnoTol)',
+                Program_Line_12='set ComfHours_' + zonename + ' = 0',
+                Program_Line_13='set DiscomfAppHotHours_' + zonename + ' = 1*ZoneTimeStep',
+                Program_Line_14='set DiscomfAppColdHours_' + zonename + ' = 0',
+                Program_Line_15='set DiscomfNonAppHotHours_' + zonename + ' = 0',
+                Program_Line_16='set DiscomfNonAppColdHours_' + zonename + ' = 0',
+                Program_Line_17='elseif (' + zonename + '_OpT < AHSTnoTol)',
+                Program_Line_18='set ComfHours_' + zonename + ' = 0',
+                Program_Line_19='set DiscomfAppHotHours_' + zonename + ' = 0',
+                Program_Line_20='set DiscomfAppColdHours_' + zonename + ' = 1*ZoneTimeStep',
+                Program_Line_21='set DiscomfNonAppHotHours_' + zonename + ' = 0',
+                Program_Line_22='set DiscomfNonAppColdHours_' + zonename + ' = 0',
                 Program_Line_23='endif',
                 Program_Line_24='elseif (RMOT > ACSTaul)',
-                Program_Line_25='set ComfHours_'+zonename+' = 0',
-                Program_Line_26='set DiscomfAppHotHours_'+zonename+' = 0',
-                Program_Line_27='set DiscomfAppColdHours_'+zonename+' = 0',
-                Program_Line_28='set DiscomfNonAppHotHours_'+zonename+' = 1*ZoneTimeStep',
-                Program_Line_29='set DiscomfNonAppColdHours_'+zonename+' = 0',
+                Program_Line_25='set ComfHours_' + zonename + ' = 0',
+                Program_Line_26='set DiscomfAppHotHours_' + zonename + ' = 0',
+                Program_Line_27='set DiscomfAppColdHours_' + zonename + ' = 0',
+                Program_Line_28='set DiscomfNonAppHotHours_' + zonename + ' = 1*ZoneTimeStep',
+                Program_Line_29='set DiscomfNonAppColdHours_' + zonename + ' = 0',
                 Program_Line_30='elseif (RMOT < AHSTall)',
-                Program_Line_31='set ComfHours_'+zonename+' = 0',
-                Program_Line_32='set DiscomfAppHotHours_'+zonename+' = 0',
-                Program_Line_33='set DiscomfAppColdHours_'+zonename+' = 0',
-                Program_Line_34='set DiscomfNonAppHotHours_'+zonename+' = 0',
-                Program_Line_35='set DiscomfNonAppColdHours_'+zonename+' = 1*ZoneTimeStep',
+                Program_Line_31='set ComfHours_' + zonename + ' = 0',
+                Program_Line_32='set DiscomfAppHotHours_' + zonename + ' = 0',
+                Program_Line_33='set DiscomfAppColdHours_' + zonename + ' = 0',
+                Program_Line_34='set DiscomfNonAppHotHours_' + zonename + ' = 0',
+                Program_Line_35='set DiscomfNonAppColdHours_' + zonename + ' = 1*ZoneTimeStep',
                 Program_Line_36='endif',
-                Program_Line_37='elseif (AdapStand == 2 )',
+                Program_Line_37='elseif (AdapStand == 2 )|| (AdapStand == 3)',
                 Program_Line_38='if (PMOT >= AHSTall) && (PMOT <= ACSTaul)',
-                Program_Line_39='if ('+zonename+'_OpT <= ACSTnoTol)',
-                Program_Line_40='if ('+zonename+'_OpT >= AHSTnoTol)',
-                Program_Line_41='set ComfHours_'+zonename+' = 1*ZoneTimeStep',
-                Program_Line_42='set DiscomfAppHotHours_'+zonename+' = 0',
-                Program_Line_43='set DiscomfAppColdHours_'+zonename+' = 0',
-                Program_Line_44='set DiscomfNonAppHotHours_'+zonename+' = 0',
-                Program_Line_45='set DiscomfNonAppColdHours_'+zonename+' = 0',
+                Program_Line_39='if (' + zonename + '_OpT <= ACSTnoTol)',
+                Program_Line_40='if (' + zonename + '_OpT >= AHSTnoTol)',
+                Program_Line_41='set ComfHours_' + zonename + ' = 1*ZoneTimeStep',
+                Program_Line_42='set DiscomfAppHotHours_' + zonename + ' = 0',
+                Program_Line_43='set DiscomfAppColdHours_' + zonename + ' = 0',
+                Program_Line_44='set DiscomfNonAppHotHours_' + zonename + ' = 0',
+                Program_Line_45='set DiscomfNonAppColdHours_' + zonename + ' = 0',
                 Program_Line_46='endif',
-                Program_Line_47='elseif ('+zonename+'_OpT > ACSTnoTol)',
-                Program_Line_48='set ComfHours_'+zonename+' = 0',
-                Program_Line_49='set DiscomfAppHotHours_'+zonename+' = 1*ZoneTimeStep',
-                Program_Line_50='set DiscomfAppColdHours_'+zonename+' = 0',
-                Program_Line_51='set DiscomfNonAppHotHours_'+zonename+' = 0',
-                Program_Line_52='set DiscomfNonAppColdHours_'+zonename+' = 0',
-                Program_Line_53='elseif ('+zonename+'_OpT < AHSTnoTol)',
-                Program_Line_54='set ComfHours_'+zonename+' = 0',
-                Program_Line_55='set DiscomfAppHotHours_'+zonename+' = 0',
-                Program_Line_56='set DiscomfAppColdHours_'+zonename+' = 1*ZoneTimeStep',
-                Program_Line_57='set DiscomfNonAppHotHours_'+zonename+' = 0',
-                Program_Line_58='set DiscomfNonAppColdHours_'+zonename+' = 0',
+                Program_Line_47='elseif (' + zonename + '_OpT > ACSTnoTol)',
+                Program_Line_48='set ComfHours_' + zonename + ' = 0',
+                Program_Line_49='set DiscomfAppHotHours_' + zonename + ' = 1*ZoneTimeStep',
+                Program_Line_50='set DiscomfAppColdHours_' + zonename + ' = 0',
+                Program_Line_51='set DiscomfNonAppHotHours_' + zonename + ' = 0',
+                Program_Line_52='set DiscomfNonAppColdHours_' + zonename + ' = 0',
+                Program_Line_53='elseif (' + zonename + '_OpT < AHSTnoTol)',
+                Program_Line_54='set ComfHours_' + zonename + ' = 0',
+                Program_Line_55='set DiscomfAppHotHours_' + zonename + ' = 0',
+                Program_Line_56='set DiscomfAppColdHours_' + zonename + ' = 1*ZoneTimeStep',
+                Program_Line_57='set DiscomfNonAppHotHours_' + zonename + ' = 0',
+                Program_Line_58='set DiscomfNonAppColdHours_' + zonename + ' = 0',
                 Program_Line_59='endif',
                 Program_Line_60='elseif (PMOT > ACSTaul)',
-                Program_Line_61='set ComfHours_'+zonename+' = 0',
-                Program_Line_62='set DiscomfAppHotHours_'+zonename+' = 0',
-                Program_Line_63='set DiscomfAppColdHours_'+zonename+' = 0',
-                Program_Line_64='set DiscomfNonAppHotHours_'+zonename+' = 1*ZoneTimeStep',
-                Program_Line_65='set DiscomfNonAppColdHours_'+zonename+' = 0',
+                Program_Line_61='set ComfHours_' + zonename + ' = 0',
+                Program_Line_62='set DiscomfAppHotHours_' + zonename + ' = 0',
+                Program_Line_63='set DiscomfAppColdHours_' + zonename + ' = 0',
+                Program_Line_64='set DiscomfNonAppHotHours_' + zonename + ' = 1*ZoneTimeStep',
+                Program_Line_65='set DiscomfNonAppColdHours_' + zonename + ' = 0',
                 Program_Line_66='elseif (PMOT < AHSTall)',
-                Program_Line_67='set ComfHours_'+zonename+' = 0',
-                Program_Line_68='set DiscomfAppHotHours_'+zonename+' = 0',
-                Program_Line_69='set DiscomfAppColdHours_'+zonename+' = 0',
-                Program_Line_70='set DiscomfNonAppHotHours_'+zonename+' = 0',
-                Program_Line_71='set DiscomfNonAppColdHours_'+zonename+' = 1*ZoneTimeStep',
+                Program_Line_67='set ComfHours_' + zonename + ' = 0',
+                Program_Line_68='set DiscomfAppHotHours_' + zonename + ' = 0',
+                Program_Line_69='set DiscomfAppColdHours_' + zonename + ' = 0',
+                Program_Line_70='set DiscomfNonAppHotHours_' + zonename + ' = 0',
+                Program_Line_71='set DiscomfNonAppColdHours_' + zonename + ' = 1*ZoneTimeStep',
                 Program_Line_72='endif',
                 Program_Line_73='endif'
-                )
+            )
             if verboseMode:
                 print('Added - CountHours_'+zonename+' Program')
     #        print([program for program in self.idf1.idfobjects['EnergyManagementSystem:Program'] if program.Name == 'CountHours_'+zonename])
@@ -133,13 +135,18 @@ def addEMSProgramsBase(self, ScriptType: str = None, verboseMode: bool = True):
             Program_Line_8='set ACSTall = 10',
             Program_Line_9='set AHSTaul = 33.5',
             Program_Line_10='set AHSTall = 10',
-            Program_Line_11='else',
-            Program_Line_12='set ACSTaul = 50',
-            Program_Line_13='set ACSTall = 50',
-            Program_Line_14='set AHSTaul = 50',
-            Program_Line_15='set AHSTall = 50',
-            Program_Line_16='endif'
-            )
+            Program_Line_11='elseif AdapStand == 3',
+            Program_Line_12='set ACSTaul = 30',
+            Program_Line_13='set ACSTall = 5',
+            Program_Line_14='set AHSTaul = 30',
+            Program_Line_15='set AHSTall = 5',
+            Program_Line_16='else',
+            Program_Line_17='set ACSTaul = 50',
+            Program_Line_18='set ACSTall = 50',
+            Program_Line_19='set AHSTaul = 50',
+            Program_Line_20='set AHSTall = 50',
+            Program_Line_21='endif'
+        )
         if verboseMode:
             print('Added - SetAppLimits Program')
     #    print([program for program in self.idf1.idfobjects['EnergyManagementSystem:Program'] if program.Name == 'SetAppLimits'])
@@ -170,8 +177,19 @@ def addEMSProgramsBase(self, ScriptType: str = None, verboseMode: bool = True):
             Program_Line_17='set ACSToffset = 3.5',
             Program_Line_18='set AHSToffset = -3.5',
             Program_Line_19='endif',
-            Program_Line_20='endif'
-            )
+            Program_Line_20='elseif (AdapStand == 3)',
+            Program_Line_21='if (CAT == 1)',
+            Program_Line_22='set ACSToffset = 2',
+            Program_Line_23='set AHSToffset = -2',
+            Program_Line_24='elseif (CAT == 2)',
+            Program_Line_25='set ACSToffset = 3',
+            Program_Line_26='set AHSToffset = -3',
+            Program_Line_27='elseif (CAT == 3)',
+            Program_Line_28='set ACSToffset = 4',
+            Program_Line_29='set AHSToffset = -4',
+            Program_Line_30='endif',
+            Program_Line_31='endif'
+        )
         if verboseMode:
             print('Added - ApplyCAT Program')
     #    print([program for program in self.idf1.idfobjects['EnergyManagementSystem:Program'] if program.Name == 'ApplyCAT'])
@@ -375,8 +393,36 @@ def addEMSProgramsBase(self, ScriptType: str = None, verboseMode: bool = True):
             Program_Line_190='set AHST = AHSTall*0.31+17.8+AHSToffset+AHSTtol',
             Program_Line_191='elseif (AdapStand == 2) && (ComfMod == 3) && (PMOT > AHSTaul)',
             Program_Line_192='set AHST = AHSTaul*0.31+17.8+AHSToffset+AHSTtol',
-            Program_Line_193='endif'
-            )
+            Program_Line_193='endif',
+            Program_Line_194='if (AdapStand == 3) && (ComfMod == 2) && (PMOT >= ACSTall) && (PMOT <= ACSTaul)',
+            Program_Line_195='set ACST = PMOT*0.37+16.8+ACSToffset+ACSTtol',
+            Program_Line_196='elseif (AdapStand == 3) && (ComfMod == 2) && (PMOT < ACSTall)',
+            Program_Line_197='set ACST = 23.9+ACSTtol',
+            Program_Line_198='elseif (AdapStand == 3) && (ComfMod == 2) && (PMOT > ACSTaul)',
+            Program_Line_199='set ACST = 26.8+ACSTtol',
+            Program_Line_200='endif',
+            Program_Line_201='if (AdapStand == 3) && (ComfMod == 2) && (PMOT >= AHSTall) && (PMOT <= AHSTaul)',
+            Program_Line_202='set AHST = PMOT*0.37+16.8+AHSToffset+AHSTtol',
+            Program_Line_203='elseif (AdapStand == 3) && (ComfMod == 2) && (PMOT < AHSTall)',
+            Program_Line_204='set AHST = 19.6+AHSTtol',
+            Program_Line_205='elseif (AdapStand == 3) && (ComfMod == 2) && (PMOT > AHSTaul)',
+            Program_Line_206='set AHST = 23.6+AHSTtol',
+            Program_Line_207='endif',
+            Program_Line_208='if (AdapStand == 3) && (ComfMod == 3) && (PMOT >= ACSTall) && (PMOT <= ACSTaul)',
+            Program_Line_209='set ACST = PMOT*0.37+16.8+ACSToffset+ACSTtol',
+            Program_Line_210='elseif (AdapStand == 3) && (ComfMod == 3) && (PMOT < ACSTall)',
+            Program_Line_211='set ACST = ACSTall*0.37+16.8+ACSToffset+ACSTtol',
+            Program_Line_212='elseif (AdapStand == 3) && (ComfMod == 3) && (PMOT > ACSTaul)',
+            Program_Line_213='set ACST = ACSTaul*0.37+16.8+ACSToffset+ACSTtol',
+            Program_Line_214='endif',
+            Program_Line_215='if (AdapStand == 3) && (ComfMod == 3) && (PMOT >= AHSTall) && (PMOT <= AHSTaul)',
+            Program_Line_216='set AHST = PMOT*0.37+16.8+AHSToffset+AHSTtol',
+            Program_Line_217='elseif (AdapStand == 3) && (ComfMod == 3) && (PMOT < AHSTall)',
+            Program_Line_218='set AHST = AHSTall*0.37+16.8+AHSToffset+AHSTtol',
+            Program_Line_219='elseif (AdapStand == 3) && (ComfMod == 3) && (PMOT > AHSTaul)',
+            Program_Line_220='set AHST = AHSTaul*0.37+16.8+AHSToffset+AHSTtol',
+            Program_Line_221='endif'
+        )
         if verboseMode:
             print('Added - SetAST Program')
     #    print([program for program in self.idf1.idfobjects['EnergyManagementSystem:Program'] if program.Name == 'SetAST'])
@@ -464,14 +510,14 @@ def addEMSProgramsBase(self, ScriptType: str = None, verboseMode: bool = True):
                 Program_Line_15='else',
                 Program_Line_16='set VST = (ACST+AHST)/2+VSToffset',
                 Program_Line_17='endif',
-                Program_Line_18='elseif AdapStand == 2',
+                Program_Line_18='elseif AdapStand == 2 || AdapStand == 3',
                 Program_Line_19='if (PMOT >= AHSTall) && (PMOT <= ACSTaul)',
                 Program_Line_20='set VST = ComfTemp+VSToffset',
                 Program_Line_21='else',
                 Program_Line_22='set VST = (ACST+AHST)/2+VSToffset',
                 Program_Line_23='endif',
                 Program_Line_24='endif'
-                )
+            )
             if verboseMode:
                 print('Added - SetVST Program')
         #    print([program for program in self.idf1.idfobjects['EnergyManagementSystem:Program'] if program.Name == 'SetVST'])
