@@ -7,8 +7,8 @@
 def inputData(self, ScriptType: str = None):
     """Input data for IDF generation."""
     print('The information you will be required to enter below will be used to generate the customised output IDFs:')
-    fullAdapStandList = [0, 1, 2]
-    self.AdapStand_List = list(int(num) for num in input("Enter the Adaptive Standard numbers separated by space (0 = CTE; 1 = EN16798-1; 2 = ASHRAE 55): ").split())
+    fullAdapStandList = [0, 1, 2, 3]
+    self.AdapStand_List = list(int(num) for num in input("Enter the Adaptive Standard numbers separated by space (0 = CTE; 1 = EN16798-1; 2 = ASHRAE 55; 3 = JPN): ").split())
     while len(self.AdapStand_List) == 0 or not all(elem in fullAdapStandList for elem in self.AdapStand_List):
         print('          Adaptive Standard numbers are not correct. Please enter the numbers again.')
         self.AdapStand_List = list(int(num) for num in input("     Enter the Adaptive Standard numbers separated by space: ").split())
@@ -199,6 +199,13 @@ def genIDF(self,
     filelist_pymod = ([file.split('.idf')[0] for file in filelist_pymod])
     # print(filelist_pymod)
 
+    AdapStand_dict = {
+        0: '[AS_CTE',
+        1: '[AS_EN16798',
+        2: '[AS_ASHRAE55',
+        3: '[AS_JPN'
+    }
+
     outputlist = []
     for file in filelist_pymod:
         filename = file
@@ -209,7 +216,7 @@ def genIDF(self,
                         for ASTtol_value in numpy.arange(self.ASTtol_value_from, self.ASTtol_value_to, self.ASTtol_value_steps):
                             outputname = (
                                 filename
-                                + '[AS_CTE'
+                                + AdapStand_dict[AdapStand_value]
                                 + '[CA_X'
                                 + '[CM_X'
                                 + '[HM_' + repr(HVACmode_value)
@@ -230,7 +237,7 @@ def genIDF(self,
                                         for ASTtol_value in numpy.arange(self.ASTtol_value_from, self.ASTtol_value_to, self.ASTtol_value_steps):
                                             outputname = (
                                                 filename
-                                                + '[AS_CTE'
+                                                + AdapStand_dict[AdapStand_value]
                                                 + '[CA_X'
                                                 + '[CM_X'
                                                 + '[HM_' + repr(HVACmode_value)
@@ -243,7 +250,7 @@ def genIDF(self,
                                                 + '.idf'
                                                 )
                                             outputlist.append(outputname)
-            elif AdapStand_value == 1:
+            elif AdapStand_value == 1 or AdapStand_value == 3:
                 for CAT_value in self.CAT_List:
                     if CAT_value not in range(0, 4):
                         continue
@@ -254,7 +261,7 @@ def genIDF(self,
                                     for ASTtol_value in numpy.arange(self.ASTtol_value_from, self.ASTtol_value_to, self.ASTtol_value_steps):
                                         outputname = (
                                             filename
-                                            + '[AS_EN16798'
+                                            + AdapStand_dict[AdapStand_value]
                                             + '[CA_' + repr(CAT_value)
                                             + '[CM_' + repr(ComfMod_value)
                                             + '[HM_' + repr(HVACmode_value)
@@ -275,7 +282,7 @@ def genIDF(self,
                                                     for ASTtol_value in numpy.arange(self.ASTtol_value_from, self.ASTtol_value_to, self.ASTtol_value_steps):
                                                         outputname = (
                                                             filename
-                                                            + '[AS_EN16798'
+                                                            + AdapStand_dict[AdapStand_value]
                                                             + '[CA_' + repr(CAT_value)
                                                             + '[CM_' + repr(ComfMod_value)
                                                             + '[HM_' + repr(HVACmode_value)
@@ -299,7 +306,7 @@ def genIDF(self,
                                     for ASTtol_value in numpy.arange(self.ASTtol_value_from, self.ASTtol_value_to, self.ASTtol_value_steps):
                                         outputname = (
                                             filename
-                                            + '[AS_EN16798'
+                                            + AdapStand_dict[AdapStand_value]
                                             + '[CA_' + repr(CAT_value)
                                             + '[CM_' + repr(ComfMod_value)
                                             + '[HM_' + repr(HVACmode_value)
@@ -320,7 +327,7 @@ def genIDF(self,
                                                     for ASTtol_value in numpy.arange(self.ASTtol_value_from, self.ASTtol_value_to, self.ASTtol_value_steps):
                                                         outputname = (
                                                             filename
-                                                            + '[AS_ASHRAE55'
+                                                            + AdapStand_dict[AdapStand_value]
                                                             + '[CA_' + repr(CAT_value)
                                                             + '[CM_' + repr(ComfMod_value)
                                                             + '[HM_' + repr(HVACmode_value)
@@ -333,6 +340,7 @@ def genIDF(self,
                                                             + '.idf'
                                                             )
                                                         outputlist.append(outputname)
+
     if verboseMode:
         print('The list of output IDFs is going to be:')
         print(*outputlist, sep="\n")
@@ -346,7 +354,8 @@ def genIDF(self,
             confirmGen = False
 
     if confirmGen == True:
-        print('Generating the following output IDF files:')
+        if verboseMode:
+            print('Generating the following output IDF files:')
         # pbar = tqdm(total=len(outputlist))
         for file in filelist_pymod:
             filename = file
@@ -373,7 +382,7 @@ def genIDF(self,
                                 SetInputData[0].Program_Line_6 = 'set AHSTtol = '+repr(ASTtol_value)
                                 outputname = (
                                     filename
-                                    + '[AS_CTE'
+                                    + AdapStand_dict[AdapStand_value]
                                     + '[CA_X'
                                     + '[CM_X'
                                     + '[HM_' + repr(HVACmode_value)
@@ -404,7 +413,7 @@ def genIDF(self,
                                                 SetInputData[0].Program_Line_10 = 'set AHSTtol = '+repr(ASTtol_value)
                                                 outputname = (
                                                     filename
-                                                    + '[AS_CTE'
+                                                    + AdapStand_dict[AdapStand_value]
                                                     + '[CA_X'
                                                     + '[CM_X'
                                                     + '[HM_' + repr(HVACmode_value)
@@ -421,7 +430,7 @@ def genIDF(self,
                                                     # time.sleep(0.1)
                                                     # pbar.update(1)
                                                 idf1.savecopy(outputname)
-                elif AdapStand_value == 1:
+                elif AdapStand_value == 1 or AdapStand_value == 3:
                     for CAT_value in self.CAT_List:
                         if CAT_value not in range(0, 4):
                             continue
@@ -437,7 +446,7 @@ def genIDF(self,
                                             SetInputData[0].Program_Line_10 = 'set AHSTtol = '+repr(ASTtol_value)
                                             outputname = (
                                                 filename
-                                                + '[AS_EN16798'
+                                                + AdapStand_dict[AdapStand_value]
                                                 + '[CA_' + repr(CAT_value)
                                                 + '[CM_' + repr(ComfMod_value)
                                                 + '[HM_' + repr(HVACmode_value)
@@ -468,7 +477,7 @@ def genIDF(self,
                                                             SetInputData[0].Program_Line_10 = 'set AHSTtol = '+repr(ASTtol_value)
                                                             outputname = (
                                                                 filename
-                                                                + '[AS_EN16798'
+                                                                + AdapStand_dict[AdapStand_value]
                                                                 + '[CA_' + repr(CAT_value)
                                                                 + '[CM_' + repr(ComfMod_value)
                                                                 + '[HM_' + repr(HVACmode_value)
@@ -501,7 +510,7 @@ def genIDF(self,
                                             SetInputData[0].Program_Line_10 = 'set AHSTtol = '+repr(ASTtol_value)
                                             outputname = (
                                                 filename
-                                                + '[AS_EN16798'
+                                                + AdapStand_dict[AdapStand_value]
                                                 + '[CA_' + repr(CAT_value)
                                                 + '[CM_' + repr(ComfMod_value)
                                                 + '[HM_' + repr(HVACmode_value)
@@ -532,7 +541,7 @@ def genIDF(self,
                                                             SetInputData[0].Program_Line_10 = 'set AHSTtol = '+repr(ASTtol_value)
                                                             outputname = (
                                                                 filename
-                                                                + '[AS_ASHRAE55'
+                                                                + AdapStand_dict[AdapStand_value]
                                                                 + '[CA_' + repr(CAT_value)
                                                                 + '[CM_' + repr(ComfMod_value)
                                                                 + '[HM_' + repr(HVACmode_value)
