@@ -57,12 +57,12 @@ class accimJob():
             iddfile = 'C:/EnergyPlusV9-4-0/Energy+.idd'
         elif EnergyPlus_version.lower() == 'ep95':
             iddfile = 'C:/EnergyPlusV9-5-0/Energy+.idd'
-        # elif EnergyPlus_version.lower() == 'ep96':
-        #     iddfile = 'C:/EnergyPlusV9-6-0/Energy+.idd'
+        elif EnergyPlus_version.lower() == 'ep96':
+            iddfile = 'C:/EnergyPlusV9-6-0/Energy+.idd'
         else:
             raise ValueError("""EnergyPlus version not supported.\n
-                                     Only works for versions between EnergyPlus 9.1 (enter Ep91) and
-                                     EnergyPlus 9.5(enter Ep95).""")
+                                     Only works for versions between EnergyPlus 9.1 (enter ep91) and
+                                     EnergyPlus 9.6(enter ep96).""")
         if verboseMode:
             print('IDD location is: '+iddfile)
         IDF.setiddname(iddfile)
@@ -145,15 +145,16 @@ class accimJob():
                 self.HVACzonelist.append([TSPtypes[i], temp1, temp2, temp3])
             del temp1, temp2, temp3
 
-            for i in range(len(self.HVACzonelist)):
-                if len(self.HVACzonelist[i][3]) == 0:
-                    print(f'There are no {self.HVACzonelist[i][0]} objects in the model')
-                else:
-                    print(f'Regarding {self.HVACzonelist[i][0]} objects:')
-                    print(f'The zones with {self.HVACzonelist[i][0]} are:')
-                    print(*self.HVACzonelist[i][1], sep="\n")
-                    print(f'And the existing ThermostatSetpoint objects related to {self.HVACzonelist[i][0]} are:')
-                    print(*self.HVACzonelist[i][3], sep="\n")
+            if verboseMode:
+                for i in range(len(self.HVACzonelist)):
+                    if len(self.HVACzonelist[i][3]) == 0:
+                        print(f'There are no {self.HVACzonelist[i][0]} objects in the model')
+                    else:
+                        print(f'Regarding {self.HVACzonelist[i][0]} objects:')
+                        print(f'The zones with {self.HVACzonelist[i][0]} are:')
+                        print(*self.HVACzonelist[i][1], sep="\n")
+                        print(f'And the existing ThermostatSetpoint objects related to {self.HVACzonelist[i][0]} are:')
+                        print(*self.HVACzonelist[i][3], sep="\n")
 
             self.zonenames_orig = []
             # todo currently all zones regardless the single or dual thermostat object are merged in zonenames_orig;
@@ -225,7 +226,7 @@ class accimJob():
                     'Coil:Cooling:DX:CurveFit:Speed': 'Cooling Coil Total Cooling Rate',
 
                     # Group – Radiative / Convective Units
-                    # todo muchos objetos tienen en outputs heating y cooling a la vez
+                    # todo many objects have heating or cooling outputs for the same field
                     'ZoneHVAC:Baseboard:RadiantConvective:Water': 'Baseboard Total Heating Rate',
                     'ZoneHVAC:Baseboard:RadiantConvective:Steam': 'Baseboard Total Heating Rate',
                     'ZoneHVAC:Baseboard:RadiantConvective:Electric': 'Baseboard Total Heating Rate',
@@ -282,21 +283,24 @@ class accimJob():
                         else:
                             self.ExisHVAC.append([HVACkeylist[i], temp, temp_zone_orig, temp_zone, temp_win])
                     except KeyError:
-                        print(f'{HVACkeylist[i]} HVAC SYSTEM IS NOT SUPPORTED')
+                        if verboseMode:
+                            print(f'{HVACkeylist[i]} HVAC SYSTEM IS NOT SUPPORTED')
                         continue
 
                 for i in range(len(self.ExisHVAC)):
                     for j in range(len(self.ExisHVAC[i][2])):
                         if self.ExisHVAC[i][2][j] not in self.zonenames_orig:
-                            print(f'"{self.ExisHVAC[i][2][j]}" is not a valid room. \n'
-                             f'That means "{self.ExisHVAC[i][1][j]}" is not named following [HVAC Zone] [HVAC Element] pattern or HVAC element is shared')
+                            if verboseMode:
+                                print(f'"{self.ExisHVAC[i][2][j]}" is not a valid room. \n'
+                                      f'That means "{self.ExisHVAC[i][1][j]}" is not named following [HVAC Zone] [HVAC Element] pattern or HVAC element is shared')
                             # raise ValueError
                             self.accimNotWorking = True
-
-                for i in range(len(self.ExisHVAC)):
-                    print(f'The names of the existing {self.ExisHVAC[i][0]} objects are:')
-                    print(*self.ExisHVAC[i][1], sep="\n")
-                    print(f'The zones related to these {self.ExisHVAC[i][0]} objects are')
-                    print(*self.ExisHVAC[i][2], sep='\n')
-                    print(f'And the windows related to these {self.ExisHVAC[i][0]} objects are:')
-                    print(*self.ExisHVAC[i][4], sep='\n')
+                
+                if verboseMode:
+                    for i in range(len(self.ExisHVAC)):
+                        print(f'The names of the existing {self.ExisHVAC[i][0]} objects are:')
+                        print(*self.ExisHVAC[i][1], sep="\n")
+                        print(f'The zones related to these {self.ExisHVAC[i][0]} objects are')
+                        print(*self.ExisHVAC[i][2], sep='\n')
+                        print(f'And the windows related to these {self.ExisHVAC[i][0]} objects are:')
+                        print(*self.ExisHVAC[i][4], sep='\n')
