@@ -26,37 +26,36 @@ def addAccis(
         confirmGen: bool = None):
     """
     Parameters
-    :param ScriptType: The default is 'VRFsystem'. Can be 'VRFsystem'or
-        'mz', or 'ExistingHVAC' or 'ex'.
-    :param Outputs: The default is 'Standard'. Can be 'Standard',
-        'Simplified' or 'Timestep'.
-    :param EnergyPlus_version: The default is 'Ep95'. Can be 'Ep91' or 'Ep95'.
+    :param ScriptType: The default is None.'vrf' for VRFsystem, 'ex_ac' for ExistingHVAC only with full air-conditioning mode, and 'ex_mm' for ExistingHVAC with mixed-mode..
+    :param Outputs: The default is None. Can be 'standard', 'simplified' or 'timestep'.
+    :param EnergyPlus_version: The default is None. Can be 'ep91', 'ep92', 'ep93', 'ep94', 'ep95' or 'ep96'.
     :param AdapStand: The default is None.
-    (0 = CTE; 1 = EN16798-1; 2 = ASHRAE 55)
+    (0 = CTE; 1 = EN16798-1; 2 = ASHRAE 55; 3 = JPN)
     :param CAT: The default is None.
     (1 = CAT I; 2 = CAT II; 3 = CAT III; 80 = 80% ACCEPT; 90 = 90% ACCEPT)
     :param ComfMod: The default is None.
     (0 = Static; 1 = OUT-CTE; 2 = OUT-SEN16798/SASHRAE55; 3 = OUT-AEN16798/AASHRAE55)
     :param HVACmode: The default is None.
     (0 = Fully Air-conditioned; 1 = Naturally ventilated; 2 = Mixed Mode)
-    :param VentCtrl:
+    :param VentCtrl: The default is None.
     (0 = Ventilates above neutral temperature; 1 = Ventilates above upper comfort limit)
-    :param VSToffset: Please refer to documentation.
-    :param MinOToffset: Please refer to documentation.
-    :param MaxWindSpeed: Please refer to documentation.
-    :param ASTtol_start: Please refer to documentation.
-    :param ASTtol_end_input: Please refer to documentation.
-    :param ASTtol_steps: Please refer to documentation.
-    :param NameSuffix: Please refer to documentation.
+    :param VSToffset: The default is 0. Please refer to documentation.
+    :param MinOToffset: The default is 50. Please refer to documentation.
+    :param MaxWindSpeed: The default is 50. Please refer to documentation.
+    :param ASTtol_start: The default is 0.1. Please refer to documentation.
+    :param ASTtol_end_input: The default is 0.1. Please refer to documentation.
+    :param ASTtol_steps: The default is 0.1. Please refer to documentation.
+    :param NameSuffix: The default is '' (an empty string). Please refer to documentation.
     :param verboseMode: True to print the process on screen. Default is True.
     :param confirmGen: True to skip confirmation of output IDF generation. Default is None.
 
     Exceptions
             DESCRIPTION. EnergyPlus version not supported.
-        Only works for versions between EnergyPlus 9.1 (enter Ep91) and
-        EnergyPlus 9.5 (enter Ep95).
+        Only works for versions between EnergyPlus 9.1 (enter ep91) and
+        EnergyPlus 9.6 (enter ep96).
 
     :return:
+    Returns nothing. Output IDFs are generated in the source folder, where input IDFs were located.
     """
     import accim.sim.accim_Main as accim_Main
     from os import listdir, remove
@@ -97,8 +96,8 @@ def addAccis(
         'ep94',
         'Ep95',
         'ep95',
-        # 'Ep96',
-        # 'ep96'
+        'Ep96',
+        'ep96'
     ]
 
     if all(objArgsDef):
@@ -113,10 +112,10 @@ def addAccis(
         while Outputs not in fullOutputsList:
             Outputs = input("Output was not correct. "
                             "Please, enter the Output (standard, simplified or timestep): ")
-        EnergyPlus_version = input("Enter the EnergyPlus version (ep91 to ep95): ")
+        EnergyPlus_version = input("Enter the EnergyPlus version (ep91 to ep96): ")
         while EnergyPlus_version not in fullEPversionsList:
             EnergyPlus_version = input("EnergyPlus version was not correct. "
-                                       "Please, enter the EnergyPlus version (ep91 to ep95): ")
+                                       "Please, enter the EnergyPlus version (ep91 to ep96): ")
     if verboseMode:
         print('ScriptType is: '+ScriptType)
     if ScriptType not in fullScriptTypeList:
@@ -158,7 +157,7 @@ def addAccis(
             notWorkingIDFs.append(file)
             continue
 
-        z.setComfFieldsPeople(verboseMode=verboseMode)
+        z.setComfFieldsPeople(EnergyPlus_version=EnergyPlus_version, verboseMode=verboseMode)
 
         if ScriptType.lower() == 'vrf':
             z.addOpTempTherm(verboseMode=verboseMode)
@@ -166,7 +165,7 @@ def addAccis(
             z.setAvailSchOn(verboseMode=verboseMode)
             z.addVRFsystemSch(verboseMode=verboseMode)
             z.addCurveObj(verboseMode=verboseMode)
-            z.addDetHVACobj(verboseMode=verboseMode)
+            z.addDetHVACobj(EnergyPlus_version=EnergyPlus_version, verboseMode=verboseMode)
             z.checkVentIsOn(verboseMode=verboseMode)
             z.addForscriptSchVRFsystem(verboseMode=verboseMode)
         elif 'ex' in ScriptType.lower():
@@ -199,9 +198,11 @@ def addAccis(
             print(file)
             print('''\n=======================END OF GENERIC IDF FILE GENERATION PROCESS=======================\n''')
 
-    print('The following IDFs will not work, and therefore these will be deleted:')
+    if verboseMode:
+        print('The following IDFs will not work, and therefore these will be deleted:')
     if len(notWorkingIDFs) > 0:
-        print(*notWorkingIDFs, sep="\n")
+        if verboseMode:
+            print(*notWorkingIDFs, sep="\n")
         filelist_pymod = ([file for file in listdir() if file.endswith('.idf')
                      and '_pymod' in file])
 
@@ -210,7 +211,8 @@ def addAccis(
                 if file in i:
                     remove(i)
     else:
-        print('None')
+        if verboseMode:
+            print('None')
 
     if verboseMode:
         print('''\n=======================START OF OUTPUT IDF FILES GENERATION PROCESS=======================\n''')
